PYG-Extension
----------------------
Welcome to PYG-Extension.

PYG-Extension is an extension Python library of torch-geometrics for materials informatics.


Quick Install
----------------------

```bash
pip install pyg_extension
```

License
----------------------
MIT

Contact
----------------------
Developer: boliqq07: 986798607@qq.com



